agentle.agents.context
======================

.. automodule:: agentle.agents.context

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      AssistantMessage
      BaseModel
      Context
      DeveloperMessage
      ExecutionState
      MutableMapping
      MutableSequence
      Sequence
      Step
      TextPart
      ToolExecutionResult
      Usage
      UserMessage
      datetime
   